# django-redis-search

[![pre-commit.ci status](https://results.pre-commit.ci/badge/github/saadmk11/django-redis-search/main.svg)](https://results.pre-commit.ci/latest/github/saadmk11/django-redis-search/main)
